Function reserve_entry
Source pub unsafe fn reserve_entry(base_ptr: *mut u8, key_ptr: *const u8) -> *mut u8
Reserve a new entry in the map
Safety
base_ptr must point to a valid initialized map
key_ptr must point to a valid key of the size specified in the map header
Panics
Panics if the key already exists in the map
Returns
Pointer to the value location, or null if the map is full